+++
title = "Replace custom keys"
tags = ["front-matter", "keys", "replace", "custom"]
draft = false
myfoo = 1
mybar = 2
+++

This post will have the `foo` key in front-matter replaced with
`myfoo` and `bar` replaced with `mybar`.
